==> nextcloud-12.0.2.tgz: nextcloud/apps/gallery/l10n/km.js <==
OC.L10N.register(
    "gallery",
    {
    "New" : "ថ្មី",
    "Error loading slideshow template" : "មាន​កំហុស​ផ្ទុក​ពុម្ព​បញ្ចាំងស្លាយ",
    "Next" : "បន្ទាប់",
    "Play" : "លេង",
    "Pause" : "ផ្អាក",
    "Previous" : "មុន",
    "Close" : "បិទ",
    "Download" : "ទាញយក",
    "Delete" : "លុប",
    "File name cannot be empty." : "ឈ្មោះ​ឯកសារ​មិន​អាច​នៅ​ទទេ​បាន​ឡើយ។",
    "Upload" : "ផ្ទុក​ឡើង",
    "Error" : "កំហុស",
    "Error while sharing" : "កំហុស​ពេល​ចែក​រំលែក",
    "Error while unsharing" : "កំពុង​ពេល​លែង​ចែក​រំលែក",
    "Error while changing permissions" : "មាន​កំហុស​នៅ​ពេល​ប្ដូរ​សិទ្ធិ",
    "Shared with you and the group {group} by {owner}" : "បាន​ចែក​រំលែក​ជាមួយ​អ្នក និង​ក្រុម {group} ដោយ {owner}",
    "Shared with you by {owner}" : "បាន​ចែក​រំលែក​ជាមួយ​អ្នក​ដោយ {owner}",
    "Share" : "ចែក​រំលែក",
    "Password protect" : "ការ​ពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "Password" : "ពាក្យសម្ងាត់",
    "Send" : "ផ្ញើ",
    "Set expiration date" : "កំណត់​ពេល​ផុត​កំណត់",
    "Expiration date" : "ពេល​ផុត​កំណត់",
    "group" : "ក្រុម",
    "Resharing is not allowed" : "មិន​អនុញ្ញាត​ឲ្យ​មាន​ការ​ចែក​រំលែក​ឡើង​វិញ",
    "Unshare" : "លែង​ចែក​រំលែក",
    "can share" : "អាច​ចែក​រំលែក",
    "can edit" : "អាច​កែប្រែ",
    "access control" : "សិទ្ធិ​បញ្ជា",
    "create" : "បង្កើត",
    "delete" : "លុប",
    "Password protected" : "បាន​ការ​ពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "Sending ..." : "កំពុង​ផ្ញើ ...",
    "Email sent" : "បាន​ផ្ញើ​អ៊ីមែល",
    "Warning" : "បម្រាម",
    "This share is password-protected" : "ការ​ចែករំលែក​នេះ​ត្រូវ​បាន​ការពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "The password is wrong. Try again." : "ពាក្យ​សម្ងាត់​ខុស​ហើយ។ ព្យាយាម​ម្ដង​ទៀត។",
    "Cancel upload" : "បោះបង់​ការ​ផ្ទុកឡើង",
    "File list" : "បញ្ជី​ឯកសារ",
    "Reasons might be:" : "មូលហេតុ​អាច​ជា៖",
    "the item was removed" : "របស់​ត្រូវ​បាន​ដក​ចេញ",
    "sharing is disabled" : "មិន​អនុញ្ញាត​ការ​ចែករំលែក",
    "Picture view" : "ទិដ្ឋភាពរូបភាព"
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/gallery/l10n/km.js <==
OC.L10N.register(
    "gallery",
    {
    "Error loading slideshow template" : "មាន​កំហុស​ផ្ទុក​ពុម្ព​បញ្ចាំងស្លាយ",
    "Next" : "បន្ទាប់",
    "Play" : "លេង",
    "Pause" : "ផ្អាក",
    "Previous" : "មុន",
    "Close" : "បិទ",
    "Download" : "ទាញយក",
    "Delete" : "លុប",
    "Share" : "ចែក​រំលែក",
    "File name cannot be empty." : "ឈ្មោះ​ឯកសារ​មិន​អាច​នៅ​ទទេ​បាន​ឡើយ។",
    "Upload" : "ផ្ទុក​ឡើង",
    "Error" : "កំហុស",
    "Error while sharing" : "កំហុស​ពេល​ចែក​រំលែក",
    "Error while unsharing" : "កំពុង​ពេល​លែង​ចែក​រំលែក",
    "Error while changing permissions" : "មាន​កំហុស​នៅ​ពេល​ប្ដូរ​សិទ្ធិ",
    "Shared with you and the group {group} by {owner}" : "បាន​ចែក​រំលែក​ជាមួយ​អ្នក និង​ក្រុម {group} ដោយ {owner}",
    "Shared with you by {owner}" : "បាន​ចែក​រំលែក​ជាមួយ​អ្នក​ដោយ {owner}",
    "Password protect" : "ការ​ពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "Password" : "ពាក្យសម្ងាត់",
    "Send" : "ផ្ញើ",
    "Set expiration date" : "កំណត់​ពេល​ផុត​កំណត់",
    "Expiration date" : "ពេល​ផុត​កំណត់",
    "group" : "ក្រុម",
    "Resharing is not allowed" : "មិន​អនុញ្ញាត​ឲ្យ​មាន​ការ​ចែក​រំលែក​ឡើង​វិញ",
    "Unshare" : "លែង​ចែក​រំលែក",
    "can share" : "អាច​ចែក​រំលែក",
    "can edit" : "អាច​កែប្រែ",
    "access control" : "សិទ្ធិ​បញ្ជា",
    "create" : "បង្កើត",
    "delete" : "លុប",
    "Password protected" : "បាន​ការ​ពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "Email sent" : "បាន​ផ្ញើ​អ៊ីមែល",
    "Warning" : "បម្រាម",
    "This share is password-protected" : "ការ​ចែករំលែក​នេះ​ត្រូវ​បាន​ការពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "The password is wrong. Try again." : "ពាក្យ​សម្ងាត់​ខុស​ហើយ។ ព្យាយាម​ម្ដង​ទៀត។",
    "Cancel upload" : "បោះបង់​ការ​ផ្ទុកឡើង",
    "File list" : "បញ្ជី​ឯកសារ",
    "Reasons might be:" : "មូលហេតុ​អាច​ជា៖",
    "the item was removed" : "របស់​ត្រូវ​បាន​ដក​ចេញ",
    "sharing is disabled" : "មិន​អនុញ្ញាត​ការ​ចែករំលែក",
    "Picture view" : "ទិដ្ឋភាពរូបភាព",
    "New" : "ថ្មី",
    "Sending ..." : "កំពុង​ផ្ញើ ..."
},
"nplurals=1; plural=0;");
